@@ -1,4 +1,4 @@
-package Sub::Name; # git description: v0.15-19-gb800ade
+package Sub::Name; # git description: v0.16-3-g4cd62f7
 # ABSTRACT: (Re)name a sub
 # KEYWORDS: subroutine function utility name rename symbol
 
@@ -54,7 +54,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.16'; # TRIAL
+our $VERSION = '0.17'; # TRIAL
 
 use Exporter 5.57 'import';
 
@@ -81,7 +81,7 @@ Sub::Name - (Re)name a sub
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -140,7 +140,7 @@ Matthijs van Duin <xmath@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Florian Ragwitz Leon Timmermans Matthijs van Duin Reini Urban gfx Dagfinn Ilmari Mannsåker Aristotle Pagaltzis J.R. Mash
+=for stopwords Karen Etheridge Leon Timmermans Florian Ragwitz Matthijs van Duin Reini Urban gfx Dagfinn Ilmari Mannsåker Aristotle Pagaltzis J.R. Mash
 
 =over 4
 
@@ -150,11 +150,11 @@ Karen Etheridge <ether@cpan.org>
 
 =item *
 
-Florian Ragwitz <rafl@debian.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =item *
 
-Leon Timmermans <fawaka@gmail.com>
+Florian Ragwitz <rafl@debian.org>
 
 =item *
 
